package com.yc.ship.module.product.service.distributorDiscount;

import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.yc.ship.framework.common.pojo.PageResult;
import com.yc.ship.framework.common.util.object.BeanUtils;
import com.yc.ship.module.product.controller.admin.distributorDiscount.vo.DistributorDiscountPageReqVO;
import com.yc.ship.module.product.controller.admin.distributorDiscount.vo.DistributorDiscountSaveReqVO;
import com.yc.ship.module.product.dal.dataobject.distributorDiscount.DistributorDiscountDO;
import com.yc.ship.module.product.dal.mysql.distributorDiscount.DistributorDiscountMapper;
import jodd.util.StringUtil;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;

import static com.yc.ship.framework.common.exception.util.ServiceExceptionUtil.exception0;

/**
 * 分销商专属折扣 Service 实现类
 *
 * @author lsq
 */
@Service
@Validated
public class DistributorDiscountServiceImpl implements DistributorDiscountService {

    @Resource
    private DistributorDiscountMapper distributorDiscountMapper;

    @Override
    public Long createDistributorDiscount(DistributorDiscountSaveReqVO createReqVO) {
        // 插入
        DistributorDiscountDO distributorDiscount = BeanUtils.toBean(createReqVO, DistributorDiscountDO.class);
        distributorDiscount.setId(IdWorker.getId(distributorDiscount));
        distributorDiscount.setAreaId(createReqVO.getAreaId().toString()) ;
        distributorDiscountMapper.insert(distributorDiscount);
        // 返回
        return distributorDiscount.getId();
    }

    @Override
    public void updateDistributorDiscount(DistributorDiscountSaveReqVO updateReqVO) {
        // 校验存在
        validateDistributorDiscountExists(updateReqVO.getId());
        // 更新
        DistributorDiscountDO updateObj = BeanUtils.toBean(updateReqVO, DistributorDiscountDO.class);
        updateObj.setAreaId(updateReqVO.getAreaId().toString()) ;
        distributorDiscountMapper.updateById(updateObj);
    }

    @Override
    public void deleteDistributorDiscount(Long id) {
        // 校验存在
        validateDistributorDiscountExists(id);
        // 删除
        distributorDiscountMapper.deleteById(id);
    }

    private void validateDistributorDiscountExists(Long id) {
        if (distributorDiscountMapper.selectById(id) == null) {
            throw exception0(600_01,"分销商专属折扣不存在");
        }
    }

    @Override
    public DistributorDiscountDO getDistributorDiscount(Long id) {
        return distributorDiscountMapper.selectById(id);
    }

    @Override
    public PageResult<DistributorDiscountDO> getDistributorDiscountPage(DistributorDiscountPageReqVO pageReqVO) {
        return distributorDiscountMapper.selectPage(pageReqVO);
    }

}